import argparse
from getpass import getpass

import itchio

parser = argparse.ArgumentParser(
    prog='python -m hstp',
    description='Build an '
)

parser.add_argument("-k", "--api-key", help="Use API key instead of username/password")

args = parser.parse_args()

l = ""

if not args.api_key:
    user = input("Username: ")
    password = getpass("Password: ")
    l = itchio.LoginAPI(user, password)
else:
    l = args.api_key

lib = itchio.Library(l)
lib.load_games()
lib.download_library()



import requests
import json
from bs4 import BeautifulSoup as soup
import requests

def LoginWeb(user, password):
        session = requests.Session()
        
        # GET the page first so we have a valid CSRF token value
        login1 = session.get("https://itch.io/login")
        s =  soup(login1.text, "html.parser")
        csrf_token = s.find("input", {"name": "csrf_token"})["value"]
        
        # Now POST the login
        r = session.post("https://itch.io/login", {"username": user, "password":password, "csrf_token": csrf_token})

        if r.status_code != 200:
            raise RuntimeError

        return session

def LoginAPI(user, password):
    r = requests.post("https://api.itch.io/login", {"username": user, "password":password, "source": "desktop"})
    if r.status_code != 200:
        raise RuntimeError
    t = json.loads(r.text)
    
    if not t["success"]:
        raise RuntimeError
    
    return t["key"]["key"]
    


from getpass import getpass
import itchio

user = input("Username: ")
password = getpass("Password: ")
 
l = itchio.LoginWeb(user, password)

url = input("Bundle URL: ")
b = itchio.Bundle(l, url)
b.load_games()


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['itchiodl', 'itchiodl.bundle_tool', 'itchiodl.downloader']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.10.0,<5.0.0', 'clint>=0.5.1,<0.6.0', 'requests']

setup_kwargs = {
    'name': 'itchiodl',
    'version': '1.1.0',
    'description': 'Python Scripts for downloading / archiving your itchio library',
    'long_description': None,
    'author': 'Peter Taylor',
    'author_email': 'me@et1.uk',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import requests
import json

from itchio.game import Game

class Library:
    def __init__(self, login):
        self.login = login
        self.games = []

    def load_game_page(self, page):
        print("Loading page", page)
        r = requests.get(f"https://api.itch.io/profile/owned-keys?page={page}", headers={"Authorization": self.login})
        j = json.loads(r.text)


        for s in j["owned_keys"]:
            self.games.append(Game(s))

        return len(j["owned_keys"])

    def load_games(self):
        page = 1
        while True:
            n = self.load_game_page(page)
            if n == 0:
                break
            page += 1

    def download_library(self):
        for game in self.games:
            game.download(self.login)
